# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/CalibrationMatricesCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.vision import CalibrationMatrices_pb2 as rst_dot_vision_dot_CalibrationMatrices__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/CalibrationMatricesCollection.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n.rst/vision/CalibrationMatricesCollection.proto\x12\nrst.vision\x1a$rst/vision/CalibrationMatrices.proto\"Q\n\x1d\x43\x61librationMatricesCollection\x12\x30\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x1f.rst.vision.CalibrationMatricesB#B!CalibrationMatricesCollectionType')
  ,
  dependencies=[rst_dot_vision_dot_CalibrationMatrices__pb2.DESCRIPTOR,])




_CALIBRATIONMATRICESCOLLECTION = _descriptor.Descriptor(
  name='CalibrationMatricesCollection',
  full_name='rst.vision.CalibrationMatricesCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.vision.CalibrationMatricesCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=181,
)

_CALIBRATIONMATRICESCOLLECTION.fields_by_name['element'].message_type = rst_dot_vision_dot_CalibrationMatrices__pb2._CALIBRATIONMATRICES
DESCRIPTOR.message_types_by_name['CalibrationMatricesCollection'] = _CALIBRATIONMATRICESCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CalibrationMatricesCollection = _reflection.GeneratedProtocolMessageType('CalibrationMatricesCollection', (_message.Message,), dict(
  DESCRIPTOR = _CALIBRATIONMATRICESCOLLECTION,
  __module__ = 'rst.vision.CalibrationMatricesCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.CalibrationMatricesCollection)
  ))
_sym_db.RegisterMessage(CalibrationMatricesCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B!CalibrationMatricesCollectionType'))
# @@protoc_insertion_point(module_scope)
