# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/GroupHypothesisCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.hri import GroupHypothesis_pb2 as rst_dot_hri_dot_GroupHypothesis__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/GroupHypothesisCollection.proto',
  package='rst.hri',
  syntax='proto2',
  serialized_pb=_b('\n\'rst/hri/GroupHypothesisCollection.proto\x12\x07rst.hri\x1a\x1drst/hri/GroupHypothesis.proto\"F\n\x19GroupHypothesisCollection\x12)\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x18.rst.hri.GroupHypothesisB\x1f\x42\x1dGroupHypothesisCollectionType')
  ,
  dependencies=[rst_dot_hri_dot_GroupHypothesis__pb2.DESCRIPTOR,])




_GROUPHYPOTHESISCOLLECTION = _descriptor.Descriptor(
  name='GroupHypothesisCollection',
  full_name='rst.hri.GroupHypothesisCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.hri.GroupHypothesisCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=153,
)

_GROUPHYPOTHESISCOLLECTION.fields_by_name['element'].message_type = rst_dot_hri_dot_GroupHypothesis__pb2._GROUPHYPOTHESIS
DESCRIPTOR.message_types_by_name['GroupHypothesisCollection'] = _GROUPHYPOTHESISCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GroupHypothesisCollection = _reflection.GeneratedProtocolMessageType('GroupHypothesisCollection', (_message.Message,), dict(
  DESCRIPTOR = _GROUPHYPOTHESISCOLLECTION,
  __module__ = 'rst.hri.GroupHypothesisCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.hri.GroupHypothesisCollection)
  ))
_sym_db.RegisterMessage(GroupHypothesisCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\035GroupHypothesisCollectionType'))
# @@protoc_insertion_point(module_scope)
